#
# spec file for package plasma5-firewall
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports
%global __requires_exclude qmlimport\\(org\\.kcm\\.firewall

%bcond_without released
Name:           plasma5-firewall
Version:        5.27.9
Release:        1.1
Summary:        Config Module for the System Firewall
License:        GPL-2.0-only OR GPL-3.0-only
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/plasma/%{version}/plasma-firewall-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-firewall-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  python3-base
BuildRequires:  cmake(KF5CoreAddons) >= 5.98.0
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5PlasmaQuick)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5X11Extras)
Requires:       firewalld
# QML imports
Requires:       kdeclarative-components
Requires:       kirigami2
Requires:       kitemmodels-imports
Requires:       knewstuff-imports
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2

%description
Config Module for the System Firewall

%lang_package

%prep
%autosetup -p1 -n plasma-firewall-%{version}

%build
%cmake_kf5 -d build -- -DBUILD_UFW_BACKEND=OFF
%cmake_build

%install
%cmake_install

%fdupes %{buildroot}

%find_lang kcm_firewall %{name}.lang

%files
%license LICENSES/*
%doc README.md
%{_kf5_appstreamdir}/org.kde.plasma.firewall.metainfo.xml
%{_kf5_applicationsdir}/kcm_firewall.desktop
%dir %{_kf5_plugindir}/plasma/
%dir %{_kf5_plugindir}/plasma/kcms/
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings/
%{_kf5_plugindir}/plasma/kcms/systemsettings/kcm_firewall.so
%dir %{_kf5_plugindir}/kf5/
%dir %{_kf5_plugindir}/kf5/plasma_firewall/
%{_kf5_plugindir}/kf5/plasma_firewall/firewalldbackend.so
%dir %{_kf5_sharedir}/kpackage/
%dir %{_kf5_sharedir}/kpackage/kcms/
%{_kf5_sharedir}/kpackage/kcms/kcm_firewall/
%{_kf5_libdir}/libkcm_firewall_core.so

%files lang -f %{name}.lang

%changelog
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- No code changes since 5.27.7
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- No code changes since 5.27.6
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- No code changes since 5.27.4
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * hint UFW about the service direction (simplified rule interface) (kde#463265)
  * Remove broken release from appstream
  * Use ecm_set_disabled_deprecation_versions
  * Remove duplicate headers between cpp/h files
  * Emit debug message if ufw executable is not found
  * Tell the ufw KAuth helper where to look for the ufw executable
  * Bugfix 458824 and 438001
  * QoL improvements
  * fix ordering
  * fix metainfo.xml
  * fix release order
  * Allow IP addresses with netmask in advanced rule editor
  * Add missing license headers
  * Remove duplicated entry from org.kde.plasma.firewall.metainfo.xml
  * Port away from KAboutData
  * Install po folder
  * Set bugReportURL
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Add FreeBSD Qt6 CI support
  * Port from RegExpValidator to RegularExpressionValidator
  * Utilize kcmutils_generate_desktop_file cmake method
  * Un-squash advanced rule editor layout (kde#456603)
  * Remove unused include
  * Actually use ${KF5_MIN_VERSION} when searching for KF5 build dependencies
  * Fix creating advanced rules
  * Request passing unit tests on Linux and BSD
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- Changes since 5.25.3:
  * Un-squash advanced rule editor layout (kde#456603)
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- Changes since 5.25.1:
  * Fix creating advanced rules
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Remove duplicate header between header cpp file
  * Port to non-deprecated KAuth includes
  * const'ify methods
  * Use Q_SIGNALS
  * Remove un implemented method
  * Fix install in kf<version>
  * Complete the Qt6 port
  * Fix qt<version>
  * Fix qt version
  * Remove unused Plasma Framework dependency
  * Adapt build system to build against qt6
  * Remove unused X11R6 dep
  * bugfix 448407
  * Use DialogButtonBox in OverlaySheet
  * Set default spacing in OverlaySheet
  * Use title: property for rule adding sheet
  * Improve UI of simplified services interface
  * chore(firewalld) cleanup old dbus call
  * Fix typo which could cause segment fault
  * Simplified rules AKA "services" rules control
  * Add missing installation of kcm_firewall.desktop file
  * Add busy property to ConnectionsModel
  * Spinner stays for the duration of timer
  * Clarify status message & code cleanup
  * Don't start timeout if password prompt is cancelled
  * Fixes issues with enabledCheckBox staying disabled and improves status text to be more representative of what's happening.
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * Add missing installation of kcm_firewall.desktop file
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Make compile without deprecated methods
  * Use Q_EMIT here
  * Use more QStringLiteral + initialize variable in header
  * Fix qml warning reported by qtc
  * Add more QStringLiteral
  * Convert KCM Desktop files to JSON & install KCM in new namespace
  * De-duplicate json metadata of KPackages
  * Use correct breeze kcm settings firewall icon
  * Fix some clazy warnings
  * USe more cmake target centric code
  * Remove unneeded X-Plasma-API from KCM metadata
  * Add FreeBSD CI
  * Add Linux CI
  * Add .kde-ci.yml
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- No code changes since 5.22.90
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Add keywords to Firewall KCM to improve search
  * Set ECM version explicitly
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Use const'ref
  * Clean up unneeded JSON parameter in kcoreaddons_add_plugin
  * Improve display of placeholder message with firewall is disabled
  * Remove not necessary Qt prefix
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- No code changes since 5.21.90
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * [kcm/core/rule] Add missing include to make bsd happy
  * Add .clang-format to gitignore file
  * Increase margins for placeholder message
  * Adjust the placeholder message to account for the firewall being on or off
  * Relocate visible: property of PlaceholderMessage
  * Give the placeholder message explanatory text
  * Tweak button wordings to conform to the HIG
  * Add a message and disable the firewall on forced failure
  * Fix crash while re-entering the firewall KCM
  * Raise minimum CMake version to 3.16
  * Use versionless Qt cmake target
  * Add a message and disable the firewall on forced failure
  * Fix crash while re-entering the firewall KCM
  * Redo the About screen
  * removing .clang format
  * Updated readme.md with contribution and setup guide
  * Introduce cmake options to disable backends
- Drop patches, now upstream:
  * 0001-Introduce-cmake-options-to-disable-backends.patch
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- Changes since 5.21.4:
  * [kcm/core/rule] Add missing include to make bsd happy
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- Changes since 5.21.3:
  * Add a message and disable the firewall on forced failure
  * Fix crash while re-entering the firewall KCM
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * typo fix
* Sun Jan 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add support for qml-autoreqprov
* Fri Jan 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
